TailwindBreakpoints class abstract

Tailwind-style layout breakpoints (Clean Architecture - Domain).

Min-width values in logical pixels. Use with MediaQuery width for mobile-first responsive layout (e.g. width >= sm means "at least sm").

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

lg → const double
1024px — large screens and up
md → const double
768px — medium screens and up
sm → const double
640px — small screens and up
xl → const double
1280px — extra large and up
xxl → const double
1536px — 2xl and up