showStepIndicator property
Optional override for whether to show the step indicator. When null, VpsFormPageConfig.showStepIndicator is used (default true).
Implementation
final bool? showStepIndicator;
Optional override for whether to show the step indicator. When null, VpsFormPageConfig.showStepIndicator is used (default true).
final bool? showStepIndicator;