RegistryDataSource class abstract
Contract for fetching registry (and optionally stations/officers) from the API.
Implementations use the package NetworkService and guardedApiCall. Throws GuardedApiException on API or network failure.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getRegistry(
{bool tokenRequired = false}) → Future< List< RegistryModel> > - Fetches the registry list from the API.
-
getRegistryWithStationsAndOfficers(
{bool tokenRequired = true}) → Future< RegistryResult> - Fetches the registry and parses data, stations, and officers from one response.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited