StationResponseModel class
Police station response model, optionally including officers. Used by citizen app when registry response includes stations.
- Annotations
-
- @freezed
Constructors
-
StationResponseModel({int? id, String? name, dynamic description, String? stationCode, DateTime? createdAt, dynamic locationId, dynamic location, List<
StationOfficer> ? officers}) -
factory
-
StationResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $StationResponseModelCopyWith<
StationResponseModel> -
no setterinherited
- createdAt → DateTime?
-
no setterinherited
- description → dynamic
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int?
-
no setterinherited
- location → dynamic
-
no setterinherited
- locationId → dynamic
-
no setterinherited
- name → String?
-
no setterinherited
-
officers
→ List<
StationOfficer> ? -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stationCode → String?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited